package com.mopub.mobileads;

import static com.mopub.common.logging.MoPubLog.AdapterLogEvent.CUSTOM;
import static com.mopub.common.logging.MoPubLog.AdapterLogEvent.LOAD_FAILED;
import static com.mopub.common.logging.MoPubLog.AdapterLogEvent.SHOW_ATTEMPTED;
import static com.mopub.common.logging.MoPubLog.AdapterLogEvent.SHOW_FAILED;
import static com.mopub.mobileads.MoPubFullscreen.ADAPTER_NAME;

import android.app.Activity;
import android.content.Context;
import android.text.TextUtils;
import android.util.Log;

import androidx.annotation.NonNull;
import androidx.annotation.Nullable;

import com.alxad.api.AlxInterstitialAD;
import com.alxad.api.AlxInterstitialADListener;
import com.mopub.common.LifecycleListener;
import com.mopub.common.Preconditions;
import com.mopub.common.logging.MoPubLog;

import java.util.Map;

/**
 * MoPub 插屏广告适配器
 */
public class AlxInterstitialAdapter extends BaseAd {
    private static final String TAG = "AlxInterstitialAdapter";
    private String mUnitid = "";
    private AlxInterstitialAD alxInterstitialAD;

    private Context mContext;

    @Nullable
    @Override
    protected LifecycleListener getLifecycleListener() {
        return null;
    }

    @Override
    public String getAdNetworkId() {
        return mUnitid == null ? "" : mUnitid;
    }

    @Override
    protected boolean checkAndInitializeSdk(@NonNull final Activity launcherActivity,
                                            @NonNull final AdData adData) {
        Log.d(TAG, "checkAndInitializeSdk");
        Preconditions.checkNotNull(launcherActivity);
        Preconditions.checkNotNull(adData);
        return false;
    }

    @Override
    protected void load(@NonNull Context context, @NonNull AdData adData) throws Exception {
        Log.d(TAG, "load");
        Preconditions.checkNotNull(context);
        Preconditions.checkNotNull(adData);
        mContext = context;

        setAutomaticImpressionAndClickTracking(false);
        //解析服务器参数
        parseServiceString(adData.getExtras());
        if (TextUtils.isEmpty(mUnitid)) {
            MoPubLog.log(getAdNetworkId(), LOAD_FAILED, ADAPTER_NAME,
                    MoPubErrorCode.ADAPTER_CONFIGURATION_ERROR.getIntCode(),
                    MoPubErrorCode.ADAPTER_CONFIGURATION_ERROR);

            if (mLoadListener != null) {
                mLoadListener.onAdLoadFailed(MoPubErrorCode.ADAPTER_CONFIGURATION_ERROR);
            }
            return;
        }
        if (!(context instanceof Activity)) {
            MoPubLog.log(getAdNetworkId(), CUSTOM, ADAPTER_NAME, "Context passed to load " +
                    "was not an Activity.");
            if (mLoadListener != null) {
                mLoadListener.onAdLoadFailed(MoPubErrorCode.ADAPTER_CONFIGURATION_ERROR);
            }
            return;
        }
        loadAds(context);
    }

    @Override
    protected void show() {
        Log.d(TAG, "show");
        MoPubLog.log(getAdNetworkId(), SHOW_ATTEMPTED, ADAPTER_NAME);
        if (alxInterstitialAD != null && alxInterstitialAD.isReady()) {
            if (mContext instanceof Activity) {
                alxInterstitialAD.show((Activity) mContext);
            } else {
                MoPubLog.log(getAdNetworkId(), SHOW_FAILED, ADAPTER_NAME,
                        MoPubErrorCode.FULLSCREEN_SHOW_ERROR.getIntCode(),
                        MoPubErrorCode.FULLSCREEN_SHOW_ERROR);
                if (mInteractionListener != null) {
                    mInteractionListener.onAdFailed(MoPubErrorCode.FULLSCREEN_SHOW_ERROR);
                }
            }
        } else {
            MoPubLog.log(getAdNetworkId(), CUSTOM, ADAPTER_NAME, "Failed to show " +
                    "alx rewarded video because it wasn't ready yet.");
            MoPubLog.log(getAdNetworkId(), SHOW_FAILED, ADAPTER_NAME,
                    MoPubErrorCode.FULLSCREEN_SHOW_ERROR.getIntCode(),
                    MoPubErrorCode.FULLSCREEN_SHOW_ERROR);
            if (mInteractionListener != null) {
                mInteractionListener.onAdFailed(MoPubErrorCode.FULLSCREEN_SHOW_ERROR);
            }
        }
    }

    @Override
    protected void onInvalidate() {
        Log.d(TAG, "onInvalidate");
        if (alxInterstitialAD != null) {
            alxInterstitialAD.destroy();
            alxInterstitialAD = null;
        }
    }

    private void parseServiceString(Map<String, String> extras) {
        try {
            if (extras == null || extras.size() == 0) {
                return;
            }
            Log.d(TAG, "--------    extras  start   ---------  ");
            mUnitid = extras.get("unitid");
            Log.d(TAG, "unitid   " + mUnitid);
            Log.d(TAG, "--------    extras  end   ---------  ");
        }catch (Exception e){
            Log.d(TAG, "parseServiceString error:" + e.getMessage());
        }
    }

    private void loadAds(Context context) {
        alxInterstitialAD = new AlxInterstitialAD();
        alxInterstitialAD.load(context, mUnitid, new AlxInterstitialADListener() {

            @Override
            public void onInterstitialAdLoaded() {
                Log.i(TAG, "onInterstitialAdLoaded");
                if (mLoadListener != null) {
                    mLoadListener.onAdLoaded();
                }
            }

            @Override
            public void onInterstitialAdLoadFail(int errorCode, String errorMsg) {
                Log.i(TAG, "onInterstitialAdLoadFail");
                MoPubLog.log(getAdNetworkId(), CUSTOM, ADAPTER_NAME, "Failed to show " +
                        "alx interstitial ad. " + errorMsg);
                MoPubLog.log(getAdNetworkId(), SHOW_FAILED, ADAPTER_NAME,
                        MoPubErrorCode.FULLSCREEN_SHOW_ERROR.getIntCode(),
                        MoPubErrorCode.FULLSCREEN_SHOW_ERROR);

                if (mLoadListener != null) {
                    mLoadListener.onAdLoadFailed(AlxServicesAdapterConfiguration.getMoPubErrorCode(errorCode));
                }
            }

            @Override
            public void onInterstitialAdClicked() {
                if (mInteractionListener != null) {
                    mInteractionListener.onAdClicked();
                }
            }

            @Override
            public void onInterstitialAdShow() {
                if (mInteractionListener != null) {
                    mInteractionListener.onAdShown();
                }
            }

            @Override
            public void onInterstitialAdClose() {
                if (mInteractionListener != null) {
                    mInteractionListener.onAdDismissed();
                }
            }

            @Override
            public void onInterstitialAdVideoStart() {
                if (mInteractionListener != null) {
                    mInteractionListener.onAdImpression();
                }
            }

            @Override
            public void onInterstitialAdVideoEnd() {
                MoPubLog.log(getAdNetworkId(), CUSTOM, ADAPTER_NAME, "onInterstitialAdVideoEnd");
            }

            @Override
            public void onInterstitialAdVideoError(int errorCode, String errorMsg) {

            }

        });
    }
}
