package com.anythink.custom.adapter;

import android.content.Context;
import android.graphics.Bitmap;
import android.text.TextUtils;
import android.util.Log;
import android.view.View;
import android.view.ViewGroup;
import android.widget.FrameLayout;

import com.alxad.api.AlxAdSDK;
import com.alxad.api.AlxNativeAD;
import com.alxad.api.AlxNativeAdListener;
import com.alxad.api.AlxNativeAdLoadListener;
import com.alxad.api.AlxNativeExpressAdListener;
import com.alxad.api.AlxSdkInitCallback;
import com.alxad.api.IAlxNativeInfo;
import com.anythink.nativead.unitgroup.api.CustomNativeAd;
import com.anythink.nativead.unitgroup.api.CustomNativeAdapter;

import java.util.ArrayList;
import java.util.List;
import java.util.Map;

/**
 * TopOn 信息流广告适配器
 */
public class AlxNativeAdapter extends CustomNativeAdapter {
    private final String TAG = AlxNativeAdapter.class.getSimpleName();

    private final String AD_STYLE_TYPE_EXPRESS = "0";
    private final String AD_STYLE_TYPE_NATIVE = "1";

    private String unitid = "";
    private String appid = "";
    private String sid = "";
    private String token = "";
    private int mImageWidth; //请求广告图的宽度：单位px
    private int mImageHeight; //请求广告图的高度: 单位px
    private String mAdStyleType; //广告样式类型： 0：是模版广告，1是原生广告
    private AlxNativeAD mNativeAD;
    private Boolean isdebug = false; //判断是否已经执行回调，防止重复执行回调方法

    @Override
    public void loadCustomNetworkAd(Context context, Map<String, Object> serverExtras, Map<String, Object> map1) {
        Log.i(TAG, "loadCustomNetworkAd");
        if (parseServer(serverExtras)) {
            initSdk(context);
        }
    }

    private boolean parseServer(Map<String, Object> serverExtras) {
        try {
            if (serverExtras.containsKey("unitid")) {
                unitid = (String) serverExtras.get("unitid");
            }
            if (serverExtras.containsKey("appid")) {
                appid = (String) serverExtras.get("appid");

            } else if (serverExtras.containsKey("appkey")) {
                appid = (String) serverExtras.get("appkey");
            }
            if (serverExtras.containsKey("appkey")) {
                sid = (String) serverExtras.get("appkey");
            } else if (serverExtras.containsKey("sid")) {
                sid = (String) serverExtras.get("sid");
            }
            if (serverExtras.containsKey("license")) {
                token = (String) serverExtras.get("license");
            } else if (serverExtras.containsKey("token")) {
                token = (String) serverExtras.get("token");
            }

            if (serverExtras.containsKey("isdebug")) {
                String test = serverExtras.get("isdebug").toString();
                Log.e(TAG, "alx debug mode:" + test);
                if (test.equals("true")) {
                    isdebug = true;
                } else {
                    isdebug = false;
                }
            } else {
                Log.e(TAG, "alx debug mode: false");
            }
            if (serverExtras.containsKey("tag")) {
                String tag = serverExtras.get("tag").toString();
                Log.e(TAG, "alx json tag:" + tag);
            }
        } catch (Exception e) {
            e.printStackTrace();
        }
        if (TextUtils.isEmpty(unitid) || TextUtils.isEmpty(token) || TextUtils.isEmpty(sid) || TextUtils.isEmpty(appid)) {
            Log.i(TAG, "alx unitid | token | sid | appid is empty");
            if (mLoadListener != null) {
                mLoadListener.onAdLoadError("", "alx unitid | token | sid | appid is empty.");
            }
            return false;
        }
        return true;
    }

    private void initSdk(final Context context) {
        try {
            Log.i(TAG, "alx ver:" + AlxAdSDK.getNetWorkVersion() + " alx token: " + token + " alx appid: " + appid + " alx sid: " + sid);

            AlxAdSDK.setDebug(isdebug);
            AlxAdSDK.init(context, token, sid, appid, new AlxSdkInitCallback() {
                @Override
                public void onInit(boolean isOk, String msg) {
                    //if (isOk){
                    startAdLoad(context);
                    //}
                }
            });
        } catch (Exception e) {
            e.printStackTrace();
        }
    }

    private void startAdLoad(final Context context) {
        AlxNativeAdLoadListener loadListener = new AlxNativeAdLoadListener() {
            @Override
            public void onAdLoadedFail(int errorCode, String errorMsg) {
                Log.i(TAG, "onAdLoadedFail:" + errorCode + ";" + errorMsg);
                if (mLoadListener != null) {
                    mLoadListener.onAdLoadError(errorCode + "", errorMsg);
                }
            }

            @Override
            public void onAdLoaded(List<IAlxNativeInfo> ads) {
                if (ads == null || ads.isEmpty()) {
                    if (mLoadListener != null) {
                        mLoadListener.onAdCacheLoaded(null);
                    }
                    return;
                }

                try {
                    TopOnData[] result = new TopOnData[ads.size()];
                    for (int i = 0; i < ads.size(); i++) {
                        IAlxNativeInfo item = ads.get(i);
                        TopOnData bean = new TopOnData(item);
                        bean.setAdData();
                        result[i] = bean;
                    }
                    if (mLoadListener != null) {
                        mLoadListener.onAdCacheLoaded(result);
                    }
                } catch (Exception e) {
                    Log.e(TAG, e.getMessage());
                    e.printStackTrace();
                    if (mLoadListener != null) {
                        mLoadListener.onAdCacheLoaded(null);
                    }
                }
            }
        };

        int adStyleType = AlxNativeAD.AlxAdSlot.TYPE_EXPRESS_AD;
        if (AD_STYLE_TYPE_NATIVE.equals(mAdStyleType)) {
            adStyleType = AlxNativeAD.AlxAdSlot.TYPE_NATIVE_AD;
        }
        mNativeAD = new AlxNativeAD(context, unitid);
        AlxNativeAD.AlxAdSlot adSlot = new AlxNativeAD.AlxAdSlot();
        adSlot.setAdStyleType(adStyleType);
        if (mImageWidth > 1 && mImageHeight > 1) {
            adSlot.setAdImageSize(mImageWidth, mImageHeight);
        }
        mNativeAD.load(adSlot, loadListener);
    }

    private class TopOnData extends CustomNativeAd {

        private IAlxNativeInfo mAlxAd;
        private View mMediaView;

        public TopOnData(IAlxNativeInfo obj) {
            mAlxAd = obj;
        }

        public void setAdData() {
            bindListener();
            if (!mAlxAd.isExpressAd()) { //如果是不是模版广告就赋值
                setTitle(mAlxAd.getTitle());
                setDescriptionText(mAlxAd.getDescription());
                setIconImageUrl(mAlxAd.getIconUrl());
                setMainImageUrl(mAlxAd.getImageUrl());
                setAdFrom(mAlxAd.getInteractionText());
            }
        }

        @Override
        public Bitmap getAdLogo() {
            return mAlxAd.getAdLogo();
        }

        @Override
        public void prepare(View view, List<View> list, FrameLayout.LayoutParams layoutParams) {
            try {
                mAlxAd.registerViewForInteraction((ViewGroup) view, list);
            } catch (Exception e) {
                e.printStackTrace();
                Log.e(TAG, e.getMessage());
            }
        }

        @Override
        public void prepare(View view, FrameLayout.LayoutParams layoutParams) {
            try {
                List<View> childViews = new ArrayList<>();
                getChildView(childViews, view);
                mAlxAd.registerViewForInteraction((ViewGroup) view, childViews);
            } catch (Exception e) {
                e.printStackTrace();
                Log.e(TAG, e.getMessage());
            }
        }

        @Override
        public boolean isNativeExpress() {
            return mAlxAd.isExpressAd();
        }

        @Override
        public View getAdMediaView(Object... objects) {
            try {
                if (mMediaView == null) {
                    mMediaView = mAlxAd.getExpressView();
                }
                mAlxAd.render();
                return mMediaView;
            } catch (Exception e) {
                e.printStackTrace();
                Log.e(TAG, e.getMessage());
            }
            return null;
        }

        private void getChildView(List<View> childViews, View view) {
            try {
                if (view instanceof ViewGroup && view != mAlxAd.getExpressView()) {
                    ViewGroup viewGroup = (ViewGroup) view;
                    for (int i = 0; i < viewGroup.getChildCount(); i++) {
                        View child = viewGroup.getChildAt(i);
                        getChildView(childViews, child);
                    }
                } else {
                    if (view != mAlxAd.getExpressView()) {
                        childViews.add(view);
                    }
                }
            } catch (Exception e) {
                e.printStackTrace();
                Log.e(TAG, e.getMessage());
            }
        }

        @Override
        public void clear(View view) {
            try {
                if (mMediaView != null) {
                    mMediaView = null;
                }
            } catch (Exception e) {
                e.printStackTrace();
                Log.e(TAG, e.getMessage());
            }
        }

        @Override
        public void destroy() {
            try {
                if (mMediaView != null) {
                    mMediaView = null;
                }
            } catch (Exception e) {
                e.printStackTrace();
                Log.e(TAG, e.getMessage());
            }
        }

        private void bindListener() {
            if (mAlxAd == null) {
                return;
            }
            if (mAlxAd.isExpressAd()) {
                mAlxAd.setAlxNativeAdListener(new AlxNativeExpressAdListener() {
                    @Override
                    public void onAdClose() {
                        notifyAdDislikeClick();
                    }

                    @Override
                    public void onRenderFail(int code, String msg) {

                    }

                    @Override
                    public void onRenderSuccess(View view) {

                    }

                    @Override
                    public void onAdClick() {
                        notifyAdClicked();
                    }

                    @Override
                    public void onAdShow() {
                        notifyAdImpression();
                    }
                });
            } else {
                mAlxAd.setAlxNativeAdListener(new AlxNativeAdListener() {
                    @Override
                    public void onAdClick() {
                        notifyAdClicked();
                    }

                    @Override
                    public void onAdShow() {
                        notifyAdImpression();
                    }

                    @Override
                    public void onAdClose() {
                        notifyAdDislikeClick();
                    }
                });
            }

        }

    }

    @Override
    public void destory() {
        if (mNativeAD != null) {
            mNativeAD.destroy();
        }
    }

    @Override
    public String getNetworkName() {
        return AlxAdSDK.getNetWorkName();
    }

    @Override
    public String getNetworkPlacementId() {
        return unitid;
    }

    @Override
    public String getNetworkSDKVersion() {
        return AlxAdSDK.getNetWorkVersion();
    }
}